﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using HugeFlow.CommandPattern;
using System.Windows.Controls.Primitives;

namespace MashupImageSearch.Commands
{
    /// <summary>
    /// 신규 Command Event를 등록하기 위한 클래스
    /// </summary>
    public class CommandEventRegister
    {
        #region Members

        static CommandEventRegister _commandRegister;
        
        #endregion Members

        #region Constructors

        /// <summary>
        /// 정적 생성자
        /// </summary>
        private CommandEventRegister()
        {
            // 여기에 Command가 지원할 새로운 컨트롤+이벤트를 추가하세요.
            CommandSubscription.CommandSubscriptions.Add(
                new CommandSubscription()
                {
                    ElementType = typeof(Selector),
                    EventName = "SelectionChanged",
                    EventHandler = new SelectionChangedEventHandler(CommandSubscriptions_SelectionChanged)
                });
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// CommandRegister를 초기화 합니다.
        /// </summary>
        public static void Init()
        {
            if (_commandRegister == null)
                _commandRegister = new CommandEventRegister();
        }

        #endregion Methods

        #region EventHandlers

        void CommandSubscriptions_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            object param = null;

            if(e.AddedItems != null && e.AddedItems.Count > 0)
                param = e.AddedItems[0];

            if(param != null && param is UIElement)
            {
                param = (sender as Selector).SelectedIndex;
            }

            CommandService.ExecuteCommand(sender, param, "SelectionChanged");
        }

        #endregion EventHandlers
    }
}
