﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Browser;
using System.Collections.Generic;
using System.Diagnostics;
using System.Xml.Linq;
using System.Linq;
using System.Windows.Media.Imaging;

namespace MashupImageSearch.Model
{
    /// <summary>
    /// Live Search에서 Image를 검색해주는 서비스
    /// </summary>
    public class LivePhotoService : PhotoServiceBase
    {
        /// <summary>
        /// 어플리케이션 ID (여기에서 발급 : http://search.live.com/developers/createapp.aspx)
        /// </summary>
        private readonly string APP_ID = "960B0BFD7406978473171FF134C86BA4D22AF66B";

        #region IPhotoService Members

        public override void SearchImageAsync(string keyword, int page, int perPage)
        {
            if (string.IsNullOrEmpty(keyword) == true)
                return;

            if (page < 1)
                throw new ArgumentOutOfRangeException("page should be bigger than 0");

            // 검색 Url 템플릿 (http://msdn.microsoft.com/en-us/library/dd251090.aspx 참고)
            string searchUrlTemplate = "http://api.search.live.net/xml.aspx?AppId={0}&Query={1}&Sources=Image&Version=2.0&Market=en-us&Adult=Moderate&Image.Count={2}&Image.Offset={3}";
            string searchUrl = string.Format(searchUrlTemplate, APP_ID, HttpUtility.UrlEncode(keyword), perPage, (page - 1) * perPage);

            // 비동기로 검색
            WebClient wc = new WebClient();
            wc.DownloadStringCompleted += new DownloadStringCompletedEventHandler(wc_DownloadStringCompleted);
            wc.DownloadStringAsync(new Uri(searchUrl, UriKind.Absolute), keyword);
        }

        #endregion

        #region Methods

        /// <summary>
        /// XML을 처리합니다.
        /// </summary>
        /// <param name="xml"></param>
        private List<Photo> XmlToImages(string xml)
        {
            XDocument xDoc = XDocument.Parse(xml);
            if (xDoc == null)
                return null;

            XNamespace mms = "http://schemas.microsoft.com/LiveSearch/2008/04/XML/multimedia";

            // LINQ 쿼리
            var query = from thumb in xDoc.Descendants(mms + "ImageResult")
                        where thumb.Element(mms + "Thumbnail").Element(mms + "ContentType").Value == "image/jpeg" ||
                              thumb.Element(mms + "Thumbnail").Element(mms + "ContentType").Value == "image/png"
                        select new Photo
                        {
                            Title = thumb.Element(mms + "Title").Value,
                            Link = thumb.Element(mms + "Url").Value,
                            Url = thumb.Element(mms + "MediaUrl").Value,
                            ThumbnailUrl = thumb.Element(mms + "Thumbnail").Element(mms + "Url").Value
                        };

            return query.ToList<Photo>();
        }

        #endregion Methods

        #region EventHandlers

        void wc_DownloadStringCompleted(object sender, DownloadStringCompletedEventArgs e)
        {
            if (e.Cancelled == true)
                return;

            if (e.Error != null)
            {
                Debug.WriteLine(e.Error.Message);
                return;
            }

            List<Photo> photos = XmlToImages(e.Result);

            OnSearchImageCompleted(e.UserState.ToString(), photos);
        }

        #endregion EventHandlers
    }
}
