﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Browser;
using System.Collections.Generic;
using System.Xml.Linq;
using System.Linq;

namespace MashupImageSearch.Model
{
    public class NaverPhotoService : PhotoServiceBase
    {
        private readonly string API_KEY = "f24b51fc3c4f27b4285b18bf07526e58";

        /// <summary>
        /// 요청 URL
        /// key : api Key
        /// query : 검색어
        /// target : image
        /// start : 시작하는 인덱스
        /// display : 검색 결과수
        /// sort : sim, date
        /// </summary>
        private readonly string REQUEST_FORMAT = "http://openapi.naver.com/search?key={0}&query={1}&target=image&start={2}&display={3}&sort=date"; 


        #region IPhotoService Members

        public override void SearchImageAsync(string keyword, int page, int perPage)
        {
            string requestUrl = string.Format(REQUEST_FORMAT, API_KEY, HttpUtility.UrlEncode(keyword), (page  - 1) * perPage + 1, perPage);

            WebClient wc = new WebClient();
            wc.DownloadStringCompleted += new DownloadStringCompletedEventHandler(wc_DownloadStringCompleted);
            wc.DownloadStringAsync(new Uri(requestUrl, UriKind.Absolute), keyword);
        }

        void wc_DownloadStringCompleted(object sender, DownloadStringCompletedEventArgs e)
        {
            if (e.Cancelled == true ||
                e.Error != null ||
                string.IsNullOrEmpty(e.Result) == true)
                return;

            XDocument xDoc = XDocument.Parse(e.Result);
            if (xDoc == null)
                return;

            var query = from c in xDoc.Descendants("item")
                        select new Photo
                        {
                            Title = c.Element("title").Value,
                            Url = c.Element("link").Value,
                            ThumbnailUrl = c.Element("thumbnail").Value
                        };

            OnSearchImageCompleted(e.UserState.ToString(), query.ToList<Photo>());
        }

        #endregion
    }
}
